const ko = require("knockout");

const Dialog = require("cattura-ui-library/src/lib/ui/dialog");
const {apiv1} = require("./api");

const template = require("./content.pug");

const NO_RECORDING = {title: "No Media Package"};

// Observables
const currentRecording = ko.observable(NO_RECORDING);

const isIncludeVerbatim = ko.observable(false);
const isIncludeRush     = ko.observable(false);

const balanceCents = ko.observable(0);
const accountMins = ko.computed(() => {
  return balanceCents() / 100;
});

const durationSec = ko.observable();
const durationFmt = ko.observable();

const costMins = ko.computed(() => {
  const mins       = durationSec() / 60;
  const costPerMin = (isIncludeRush() ? 2 : 1) + (isIncludeVerbatim() ? 0.25 : 0);

  return Math.ceil(mins * costPerMin);
});

const remaining = ko.computed(() => {
  return accountMins() - costMins();
});

function makeDialog (plugin)
{
    return Dialog({
        open (mediaPackage)
        {
            // Populate balance from Rev plugin
            plugin.services.getBalanceCents().then(balanceCents);

            // Update media package
            currentRecording(mediaPackage);

            const ms  = mediaPackage.duration._milliseconds;
            durationSec(ms / 1000 + 1);
            durationFmt(new Date(ms).toISOString().substr(11, 8));

            this.show();
        },

        close ()
        {
            this.hide();

            currentRecording(NO_RECORDING);
        },

        submit ()
        {
            // Get required props
            const mediaPkgId = currentRecording().id;

            // Close b/c we're now going to upload and don't want to block UI
            this.hide();

            currentRecording(NO_RECORDING);

            // Begin upload
            plugin.services.upload({
                mediaPackageId: mediaPkgId,
                isRush:         isIncludeRush(),
                isVerbatim:     isIncludeVerbatim(),
            })
            .catch(error => {
                // TODO: Handle failed to upload
            });
        },

        isIncludeRush: isIncludeRush,
        accountMins: accountMins,
        durationSec: durationSec,
        durationFmt: durationFmt,
        costMins: costMins,
        remaining: remaining,
        mediaPackage: currentRecording
    }, {
        template: template
    });
}

module.exports = makeDialog;
